@@ -6,8 +6,7 @@ test_that('statistics', {
   expect_identical(length(R), nrow(rs$CP))
 
   ## Try computation and check that all values are coherent
-  expect_silent(MeanR <- meanR(data, fit, transforms, "loewe",
-                               R, rs$CP, reps))
+  expect_silent(MeanR <- rs$meanR)
 
   expect_true(inherits(MeanR, "meanR"))
   expect_true(MeanR$FStat > 0)
@@ -19,8 +18,8 @@ test_that('statistics', {
   R <- rnorm(length(reps))
   CP <- rWishart(1, length(reps), diag(1, length(reps)))[,,1]
 
-  expect_silent(MeanR <- meanR(data, fit, transforms, "loewe",
-                               R, CP, reps))
+  expect_silent(MeanR <- fitSurface(data, fit, transforms, "loewe",
+                               R, CP, reps, statistic = "meanR")$meanR)
   expect_true(MeanR$FStat > 0)
   expect_true(MeanR$p.value >= 0)
   expect_true(MeanR$p.value <= 1)
